==> ejc-technologymanage-impl-3.0.0-20220425.074720-12-sources.jar: com/ejianc/business/constructor/bean/JsglViewEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 技术管理视图
 * 
 * @author generator
 * 
 */
 @TableName("v_technologymanage_all")
public class JsglViewEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 
    @TableField(value="org_id")
    private Long orgId; // 
    @TableField(value="org_name")
    private String orgName; // 
    @TableField(value="bill_state")
    private Integer billState; // 
    @TableField(value="create_user_name")
    private String createUserName; // 
    @TableField(value="operator_id")
    private Long operatorId; // 
    @TableField(value="operator_name")
    private String operatorName; // 
    @TableField(value="update_user_name")
    private String updateUserName; // 
    @TableField(value="remark")
    private String remark; // 
    @TableField(value="famc")
    private String famc; // 
    @TableField(value="falx_id")
    private Long falxId; // 
    @TableField(value="falx_name")
    private String falxName; // 
    @TableField(value="gcxmmc_id")
    private Long gcxmmcId; // 
    @TableField(value="gcxmmc_name")
    private String gcxmmcName; // 
    @TableField(value="sgdw_id")
    private Long sgdwId; // 
    @TableField(value="sgdw_name")
    private String sgdwName; // 
    @TableField(value="gcjd_id")
    private Long gcjdId; // 
    @TableField(value="gcjd_name")
    private String gcjdName; // 
    @TableField(value="gclb_id")
    private Long gclbId; // 
    @TableField(value="gclb_name")
    private String gclbName; // 
    @TableField(value="jglx_id")
    private Long jglxId; // 
    @TableField(value="jglx_name")
    private String jglxName; // 
    @TableField(value="ssxjz_id")
    private Long ssxjzId; // 
    @TableField(value="ssxjz_name")
    private String ssxjzName; // 
    @TableField(value="htkgrq")
    private Date htkgrq; // 
    @TableField(value="htjgrq")
    private Date htjgrq; // 
    @TableField(value="jlsq")
    private Integer jlsq; // 
    @TableField(value="tags")
    private String tags; // 
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }
    public Long getFalxId() {
        return falxId;
    }

    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    public Long getGcxmmcId() {
        return gcxmmcId;
    }

    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }
    public Long getGclbId() {
        return gclbId;
    }

    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }
    public Long getJglxId() {
        return jglxId;
    }

    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }
    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
    
}

==> ejc-technologymanage-impl-3.0.0-20251009.061228-54-sources.jar: com/ejianc/business/constructor/bean/JsglViewEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 技术管理视图
 * 
 * @author generator
 * 
 */
 @TableName("v_technologymanage_all")
public class JsglViewEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 
    @TableField(value="org_id")
    private Long orgId; // 
    @TableField(value="org_name")
    private String orgName; // 
    @TableField(value="bill_state")
    private Integer billState; // 
    @TableField(value="create_user_name")
    private String createUserName; // 
    @TableField(value="operator_id")
    private Long operatorId; // 
    @TableField(value="operator_name")
    private String operatorName; // 
    @TableField(value="update_user_name")
    private String updateUserName; // 
    @TableField(value="remark")
    private String remark; // 
    @TableField(value="famc")
    private String famc; // 
    @TableField(value="falx_id")
    private Long falxId; // 
    @TableField(value="falx_name")
    private String falxName; // 
    @TableField(value="gcxmmc_id")
    private Long gcxmmcId; // 
    @TableField(value="gcxmmc_name")
    private String gcxmmcName; // 
    @TableField(value="sgdw_id")
    private Long sgdwId; // 
    @TableField(value="sgdw_name")
    private String sgdwName; // 
    @TableField(value="gcjd_id")
    private Long gcjdId; // 
    @TableField(value="gcjd_name")
    private String gcjdName; // 
    @TableField(value="gclb_id")
    private Long gclbId; // 
    @TableField(value="gclb_name")
    private String gclbName; // 
    @TableField(value="jglx_id")
    private Long jglxId; // 
    @TableField(value="jglx_name")
    private String jglxName; // 
    @TableField(value="ssxjz_id")
    private Long ssxjzId; // 
    @TableField(value="ssxjz_name")
    private String ssxjzName; // 
    @TableField(value="htkgrq")
    private Date htkgrq; // 
    @TableField(value="htjgrq")
    private Date htjgrq; // 
    @TableField(value="jlsq")
    private Integer jlsq; // 
    @TableField(value="tags")
    private String tags; // 
    @TableField(value="gd")
    private Integer gd; // 是否完成归档(0:是 1：否)

    public Integer getGd() {
        return gd;
    }

    public void setGd(Integer gd) {
        this.gd = gd;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }
    public Long getFalxId() {
        return falxId;
    }

    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    public Long getGcxmmcId() {
        return gcxmmcId;
    }

    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }
    public Long getGclbId() {
        return gclbId;
    }

    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }
    public Long getJglxId() {
        return jglxId;
    }

    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }
    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
    
}
